/**
 * @file	xmlmem.h
 * @brief	Memory operations for XML data.
 * @date	2004.02.14
 * @author	Steel Wheels Project
 * @par Copyright
 *   Copyright (C) 2004 Steel Wheels Project.
 *   All right reserved.
 * @par Description
 *   The libxml2 library has custom memory allocation functions and
 *   they can be replaced by the user.
 *
 *   This file defines custom memory allocation functions used to
 *   make additional memory spaces which contains the information
 *   for each nodes and documents.
 */

#if !defined(XMLMEM_H_INCLUDED)
/** Avoid include twice */
#define XMLMEM_H_INCLUDED

#include <LibXmlKit/xmltype.h>

/** import #XmlDoc class type */
@class XmlDoc ;
/** import #XmlNode class type */
@class XmlNode ;

/**
 * @brief	Initialize the memory system for XML processing.
 * @par Description
 *   Initialize the memory system for XML processing.
 *   This function is called in the startup initializer in XmlDoc class.
 *   DO NOT CALL this method in the other place.
 */
void
xml_mem_init(void) ;

/**
 * @brief	Get XmlDoc instance from xmlDocPtr.
 * @param	doc xml document data.
 * @return	Instance of XmlDoc class.
 * @par Description
 *   Get XmlDoc instance from xmlDocPtr.
 */
XmlDoc *
xml_mem_doc_ptr2obj(xmlDocPtr doc) ;

/**
 * @brief	Get XmlNode instance from xmlNodePtr.
 * @return	Instance of XmlNode class.
 * @param	node xmlNode to get pair.
 * @par Description
 *   Get #XmlNode object from xmlNodePtr.
 */
XmlNode *
xml_mem_node_ptr2obj(xmlNodePtr node) ;

#endif /* !defined(XMLMEM_H_INCLUDED) */

