/**
 * @file	xmlnodeset.h
 * @brief	Definition of #XmlNodeSet class.
 * @date	2004.02.14
 * @author	Steel Wheels Project
 * @par Copyright
 *   Copyright (C) 2004 Steel Wheels Project.
 *   All right reserved.
 * @par Description
 *   #XmlNodeSet class definition.
 *   #XmlNodeSet class operates set of #XmlNode objects.
 */

#ifndef XMLNODESET_H_INCLUDED
#define XMLNODESET_H_INCLUDED

#include <LibXmlKit/xmlnode.h>

/**
 * @brief	Set of #XmlNode objects.
 * @par Description
 *   Set of #XmlNode objects.
 */
@interface XmlNodeSet : XmlObject 
{
	/** Set data structure */
	xmlNodeSetPtr	node_set ;
}

/**
 * @brief	Initialize object
 * @return	New object.
 * @par Description
 *    Initialize object.
 */
- init ;

/**
 * @brief	Initialize object by given node set.
 * @return	New object.
 * @param	nodeset Source node set. This data will be destroyed
 *		with this object.
 * @par Description
 *    Initialize object.
 */
- initXmlNodeSet: (xmlNodeSetPtr) nodeset ;

/**
 * @brief	Deallocate object.
 * @par Description
 *    Deallocate object.
 */
- (void) dealloc ;

/**
 * @brief	Get number of nodes in the set.
 * @return	Number of nodes.
 * @par Description
 *   Get number of nodes in the set.
 */
- (unsigned int) num ;

/**
 * @brief	Get one node from node set.
 * @retval	obj Node object.
 * @retval	nil Node set is empty or invalid index was given.
 * @param	idx Index number to get.
 * @par Description
 *    Get one node from node set by index.
 */
- (XmlNode *) nodeAtIndex: (unsigned int) idx ;

/**
 * @brief	Make node set which contains all children in this set.
 * @return	New node set.
 * @par Description
 *   Make node set which contains all children in this set.
 */
- (XmlNodeSet *) makeSubtreeSet ;

@end

#endif /* XMLNODESET_H_INCLUDED */

