/**
 * @file	xmlobject.h
 * @brief	#XmlObject class definition.
 * @date	2004.02.14
 * @author	Steel Wheels Project
 * @par Copyright
 *   Copyright (C) 2004 Steel Wheels Project.
 *   All right reserved.
 * @par Description
 *   #XmlObject class definition.
 *   All other classes in LibXmlKit inherits this class.
 */

#ifndef XMLOBJECT_H_INCLUDED
#define XMLOBJECT_H_INCLUDED

#include <LibXmlKit/xmlsysdep.h>
#include <LibXmlKit/xmltype.h>

/**
 * @brief	Super class of all the other classes.
 * @par Description
 *   Super class of all the other classes.
 */
@interface XmlObject : OBJECT 
{
#	ifndef __APPLE__
	/** Reference count */
	int		ref_count ;
#	endif
}

  /**
   * @brief	Initialize instance of XmlObject class.
   * @return	The object itself.
   * @par Description
   *   Initialize instance of XmlObject class.
   */
  - init ;
  
  /**
   * @brief	Release resource for the object.
   * @par Description
   *   Release resource for the object.
   */
  - (void) dealloc ;
  
  /**
   * @brief	Increment the reference count.
   * @par Description
   *   Increment the reference count.
   *   This method is supported only Unix systems. Not MacOS-X.
   */
  - retain ;
  
  /**
   * @brief	Decrement the reference count.
   * @par Description
   *   Decrement the reference count.
   *   If the reference count is zero, the object is disposed.
   *   This method is supported only Unix systems. Not MacOS-X.
   */
  - (oneway void) release ;
 
@end

#endif /* XMLOBJECT_H_INCLUDED */

