/**
 * @file	xmlregexp.h
 * @brief	#XmlRegexp class definition.
 * @date	2004.02.29
 * @author	Steel Wheels Project
 * @par Copyright
 *   Copyright (C) 2004 Steel Wheels Project.
 *   All right reserved.
 * @par Description
 *   #XmlRegexp class definition.
 *   #XmlRegexp class operates regular expression for XML data processing.
 */

#if !defined(XMLREGEXP_H_INCLUDED)
#define	XMLREGEXP_H_INCLUDED

#include <LibXmlKit/xmlobject.h>

/**
 * @brief	#XmlRegexp object.
 * @par Description
 *   #XmlRegexp object.
 */
@interface XmlRegexp : XmlObject 
{
	/** Regular expression */
	xmlRegexpPtr			regexp_ptr ;
}

/**
 * @brief	Initialize with regular expression string.
 * @param	expstr String for regular expression
 * @par Description
 *   Initialize with regular expression string.
 */
+ newWithRegexp: (const xmlChar *) expstr ;

/**
 * @brief	Initialize by empty regular expression.
 * @par Description
 *    Initialize by empty regular expression.
 */
- init ;

/**
 * @brief	Initialize regular expression for XML document.
 * @par Description
 *    Initialize the regular expression for XML document.
 */
- initWithRegexp: (xmlRegexpPtr) regexp ;

/**
 * @brief	Compile regular expression.
 * @retval	true Compilation successed.
 * @retval	false Compilation failed.
 * @param	expstr String for regular expression.
 * @par Description
 *    Compile regular expression.
 */
- (BOOL) compile: (const xmlChar *) expstr ;

/**
 * @brief	Evaluate string by compiled expression.
 * @retval	true Source string matched.
 * @retval	false Source string did not matched.
 * @param 	src Source string.
 * @par Description
 *    Evaluate string by compiled expression.
 * @warning
 *    You have to call compile() method before calling this method.
 */
- (BOOL) evaluate: (const xmlChar *) src ;

/**
 * @brief	Print content of regexp data.
 * @param	outfp Output data stream.
 * @par Description
 *    Print content of regexp data.
 */
- (void) print: (FILE *) outfp ;

@end

#endif	/* !defined(XMLREGEXP_H_INCLUDED) */

