/**
 * @file	xpath.h
 * @brief	#XPath class definition.
 * @date	2004.02.14
 * @author	Steel Wheels Project
 * @par Copyright
 *   Copyright (C) 2004 Steel Wheels Project.
 *   All right reserved.
 * @par Description
 *   #XPath class definition.
 *   #XPath class operates xpath expression for XML data processing.
 */

#if !defined(XPATH_H_INCLUDED)
#define	XPATH_H_INCLUDED

#include <LibXmlKit/xmlobject.h>
#include <LibXmlKit/xmlnodeset.h>

@class XmlDoc ;

/**
 * @brief	#XPath object.
 * @par Description
 *   #XPath object.
 */
@interface XPath : XmlObject 
{
	/** Xpath expression */
	xmlXPathCompExprPtr		xpath_exp ;

	/** Result of evaluation */
	xmlXPathObjectPtr		xpath_eval_result ;
}

/**
 * @brief	Initialize the XPath data for XML document.
 * @par Description
 *    Initialize the XPath data for XML document.
 */
- init ;

/**
 * @brief	Compile XPath expression.
 * @retval	true Compilation successed.
 * @retval	false Compilation failed.
 * @param	exp XPath expression.
 * @par Description
 *    Compile XPath expression.
 */
- (BOOL) compile: (const xmlChar *) exp ;

/**
 * @brief	Evaluate document by compiled expression.
 * @retval	true Some nodes were matched.
 * @retval	false No nodes were matched.
 * @par Description
 *    Evaluate document by compiled expression.
 * @warning
 *    You have to call compile() method before calling this method.
 */
- (BOOL) evaluate: (XmlDoc *) doc ;

/**
 * @brief	Get result of evaluation.
 * @return	Matched node set.
 * @par Description
 *    Get result of evaluation.
 */
- (XmlNodeSet *) getResultNodeSet ;

@end

#endif	/* !defined(XPATH_H_INCLUDED) */

